@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,14 +12,14 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "comment.h"
 
 #include <typeinfo>
 
-#include <QRegExp>
+#include <QDebug>
 #include <QStringList>
 
 /**
@@ -84,3 +84,8 @@ void Comment::setUseCommand(bool useCommand)
 bool Comment::isComment(const Element &other) {
     return typeid(other) == typeid(Comment);
 }
+
+QDebug operator<<(QDebug dbg, const Comment &comment) {
+    dbg.nospace() << "Comment " << comment.text();
+    return dbg;
+}
