@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "fieldinput.h"
@@ -23,10 +23,10 @@
 #include <QDate>
 #include <QSignalMapper>
 #include <QSpinBox>
+#include <QPushButton>
+#include <QInputDialog>
 
-#include <KLocale>
-#include <KPushButton>
-#include <KInputDialog>
+#include <KLocalizedString>
 
 #include "file.h"
 #include "entry.h"
@@ -52,15 +52,15 @@ public:
     const Element *element;
 
     FieldInputPrivate(FieldInput *parent)
-            : p(parent), colorWidget(NULL), starRatingWidget(NULL), fieldLineEdit(NULL), fieldListEdit(NULL), fieldInputType(KBibTeX::SingleLine), preferredTypeFlag(KBibTeX::tfSource), bibtexFile(NULL), element(NULL) {
+            : p(parent), colorWidget(nullptr), starRatingWidget(nullptr), fieldLineEdit(nullptr), fieldListEdit(nullptr), fieldInputType(KBibTeX::SingleLine), preferredTypeFlag(KBibTeX::tfSource), bibtexFile(nullptr), element(nullptr) {
         /// nothing
     }
 
     ~FieldInputPrivate() {
-        if (colorWidget != NULL) delete colorWidget;
-        else if (starRatingWidget != NULL) delete starRatingWidget;
-        else if (fieldLineEdit != NULL) delete fieldLineEdit;
-        else if (fieldListEdit != NULL) delete fieldListEdit;
+        if (colorWidget != nullptr) delete colorWidget;
+        else if (starRatingWidget != nullptr) delete starRatingWidget;
+        else if (fieldLineEdit != nullptr) delete fieldLineEdit;
+        else if (fieldListEdit != nullptr) delete fieldListEdit;
     }
 
     void createGUI() {
@@ -79,12 +79,12 @@ public:
         case KBibTeX::Month: {
             fieldLineEdit = new FieldLineEdit(preferredTypeFlag, typeFlags, false, p);
             layout->addWidget(fieldLineEdit);
-            KPushButton *monthSelector = new KPushButton(KIcon("view-calendar-month"), "");
+            QPushButton *monthSelector = new QPushButton(QIcon::fromTheme(QStringLiteral("view-calendar-month")), QString());
             monthSelector->setToolTip(i18n("Select a predefined month"));
             fieldLineEdit->prependWidget(monthSelector);
 
             QSignalMapper *sm = new QSignalMapper(monthSelector);
-            connect(sm, SIGNAL(mapped(int)), p, SLOT(setMonth(int)));
+            connect(sm, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), p, &FieldInput::setMonth);
             QMenu *monthMenu = new QMenu(monthSelector);
             for (int i = 1; i <= 12; ++i) {
                 QAction *monthAction = monthMenu->addAction(QDate::longMonthName(i, QDate::StandaloneFormat), sm, SLOT(map()));
@@ -93,13 +93,31 @@ public:
             monthSelector->setMenu(monthMenu);
         }
         break;
+        case KBibTeX::Edition: {
+            fieldLineEdit = new FieldLineEdit(preferredTypeFlag, typeFlags, false, p);
+            layout->addWidget(fieldLineEdit);
+            QPushButton *editionSelector = new QPushButton(QIcon::fromTheme(QStringLiteral("clock")), QString());
+            editionSelector->setToolTip(i18n("Select a predefined edition"));
+            fieldLineEdit->prependWidget(editionSelector);
+
+            QSignalMapper *sm = new QSignalMapper(editionSelector);
+            connect(sm, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), p, &FieldInput::setEdition);
+            QMenu *editionMenu = new QMenu(editionSelector);
+            static const QStringList ordinals{i18n("1st"), i18n("2nd"), i18n("3rd"), i18n("4th"), i18n("5th"), i18n("6th"), i18n("7th"), i18n("8th"), i18n("9th"), i18n("10th"), i18n("11th"), i18n("12th"), i18n("13th"), i18n("14th"), i18n("15th"), i18n("16th")};
+            for (int i = 0; i < ordinals.length(); ++i) {
+                QAction *editionAction = editionMenu->addAction(ordinals[i], sm, SLOT(map()));
+                sm->setMapping(editionAction, i + 1);
+            }
+            editionSelector->setMenu(editionMenu);
+        }
+        break;
         case KBibTeX::CrossRef: {
             fieldLineEdit = new FieldLineEdit(preferredTypeFlag, typeFlags, false, p);
             layout->addWidget(fieldLineEdit);
-            KPushButton *referenceSelector = new KPushButton(KIcon("flag-gree"), ""); ///< find better icon
+            QPushButton *referenceSelector = new QPushButton(QIcon::fromTheme(QStringLiteral("flag-green")), QString()); ///< find better icon
             referenceSelector->setToolTip(i18n("Select an existing entry"));
             fieldLineEdit->prependWidget(referenceSelector);
-            connect(referenceSelector, SIGNAL(clicked()), p, SLOT(selectCrossRef()));
+            connect(referenceSelector, &QPushButton::clicked, p, &FieldInput::selectCrossRef);
         }
         break;
         case KBibTeX::Color: {
@@ -134,13 +152,13 @@ public:
 
     void clear() {
         disableModifiedSignal();
-        if (fieldLineEdit != NULL)
-            fieldLineEdit->setText("");
-        else if (fieldListEdit != NULL)
+        if (fieldLineEdit != nullptr)
+            fieldLineEdit->setText(QString());
+        else if (fieldListEdit != nullptr)
             fieldListEdit->clear();
-        else if (colorWidget != NULL)
+        else if (colorWidget != nullptr)
             colorWidget->clear();
-        else if (starRatingWidget != NULL)
+        else if (starRatingWidget != nullptr)
             starRatingWidget->unsetValue();
         enableModifiedSignal();
     }
@@ -151,13 +169,13 @@ public:
         disableModifiedSignal();
 
         bool result = false;
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             result = fieldLineEdit->reset(value);
-        else if (fieldListEdit != NULL)
+        else if (fieldListEdit != nullptr)
             result = fieldListEdit->reset(value);
-        else if (colorWidget != NULL)
+        else if (colorWidget != nullptr)
             result = colorWidget->reset(value);
-        else if (starRatingWidget != NULL)
+        else if (starRatingWidget != nullptr)
             result = starRatingWidget->reset(value);
 
         enableModifiedSignal();
@@ -166,61 +184,73 @@ public:
 
     bool apply(Value &value) const {
         bool result = false;
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             result = fieldLineEdit->apply(value);
-        else if (fieldListEdit != NULL)
+        else if (fieldListEdit != nullptr)
             result = fieldListEdit->apply(value);
-        else if (colorWidget != NULL)
+        else if (colorWidget != nullptr)
             result = colorWidget->apply(value);
-        else if (starRatingWidget != NULL)
+        else if (starRatingWidget != nullptr)
             result = starRatingWidget->apply(value);
         return result;
     }
 
+    bool validate(QWidget **widgetWithIssue, QString &message) const {
+        if (fieldLineEdit != nullptr)
+            return fieldLineEdit->validate(widgetWithIssue, message);
+        else if (fieldListEdit != nullptr)
+            return fieldListEdit->validate(widgetWithIssue, message);
+        else if (colorWidget != nullptr)
+            return colorWidget->validate(widgetWithIssue, message);
+        else if (starRatingWidget != nullptr)
+            return starRatingWidget->validate(widgetWithIssue, message);
+        return false;
+    }
+
     void setReadOnly(bool isReadOnly) {
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             fieldLineEdit->setReadOnly(isReadOnly);
-        else if (fieldListEdit != NULL)
+        else if (fieldListEdit != nullptr)
             fieldListEdit->setReadOnly(isReadOnly);
-        else if (colorWidget != NULL)
+        else if (colorWidget != nullptr)
             colorWidget->setReadOnly(isReadOnly);
-        else if (starRatingWidget != NULL)
+        else if (starRatingWidget != nullptr)
             starRatingWidget->setReadOnly(isReadOnly);
     }
 
     void setFile(const File *file) {
         bibtexFile = file;
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             fieldLineEdit->setFile(file);
-        if (fieldListEdit != NULL)
+        if (fieldListEdit != nullptr)
             fieldListEdit->setFile(file);
     }
 
     void setElement(const Element *element) {
         this->element = element;
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             fieldLineEdit->setElement(element);
-        if (fieldListEdit != NULL)
+        if (fieldListEdit != nullptr)
             fieldListEdit->setElement(element);
     }
 
     void setFieldKey(const QString &fieldKey) {
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             fieldLineEdit->setFieldKey(fieldKey);
-        if (fieldListEdit != NULL)
+        if (fieldListEdit != nullptr)
             fieldListEdit->setFieldKey(fieldKey);
     }
 
     void setCompletionItems(const QStringList &items) {
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             fieldLineEdit->setCompletionItems(items);
-        if (fieldListEdit != NULL)
+        if (fieldListEdit != nullptr)
             fieldListEdit->setCompletionItems(items);
     }
 
     bool selectCrossRef() {
-        Q_ASSERT_X(fieldLineEdit != NULL, "void FieldInput::FieldInputPrivate::selectCrossRef()", "fieldLineEdit is invalid");
-        if (bibtexFile == NULL) return false;
+        Q_ASSERT_X(fieldLineEdit != nullptr, "void FieldInput::FieldInputPrivate::selectCrossRef()", "fieldLineEdit is invalid");
+        if (bibtexFile == nullptr) return false;
 
         /// create a standard input dialog with a list of all keys (ids of entries)
         bool ok = false;
@@ -229,9 +259,9 @@ public:
 
         /// remove own id
         const Entry *entry = dynamic_cast<const Entry *>(element);
-        if (entry != NULL) list.removeOne(entry->id());
+        if (entry != nullptr) list.removeOne(entry->id());
 
-        QString crossRef = KInputDialog::getItem(i18n("Select Cross Reference"), i18n("Select the cross reference to another entry:"), list, 0, false, &ok, p);
+        QString crossRef = QInputDialog::getItem(p, i18n("Select Cross Reference"), i18n("Select the cross reference to another entry:"), list, 0, false, &ok);
 
         if (ok && !crossRef.isEmpty()) {
             /// insert selected cross reference into edit widget
@@ -244,25 +274,25 @@ public:
     }
 
     void enableModifiedSignal() {
-        if (fieldLineEdit != NULL)
-            connect(fieldLineEdit, SIGNAL(textChanged(QString)), p, SIGNAL(modified()));
-        if (fieldListEdit != NULL)
-            connect(fieldListEdit, SIGNAL(modified()), p, SIGNAL(modified()));
-        if (colorWidget != NULL)
-            connect(colorWidget, SIGNAL(modified()), p, SIGNAL(modified()));
-        if (starRatingWidget != NULL)
-            connect(starRatingWidget, SIGNAL(modified()), p, SIGNAL(modified()));
+        if (fieldLineEdit != nullptr)
+            connect(fieldLineEdit, &FieldLineEdit::textChanged, p, &FieldInput::modified);
+        if (fieldListEdit != nullptr)
+            connect(fieldListEdit, &FieldListEdit::modified, p, &FieldInput::modified);
+        if (colorWidget != nullptr)
+            connect(colorWidget, &ColorLabelWidget::modified, p, &FieldInput::modified);
+        if (starRatingWidget != nullptr)
+            connect(starRatingWidget, &StarRatingFieldInput::modified, p, &FieldInput::modified);
     }
 
     void disableModifiedSignal() {
-        if (fieldLineEdit != NULL)
-            disconnect(fieldLineEdit, SIGNAL(textChanged(QString)), p, SIGNAL(modified()));
-        if (fieldListEdit != NULL)
-            disconnect(fieldListEdit, SIGNAL(modified()), p, SIGNAL(modified()));
-        if (colorWidget != NULL)
-            disconnect(colorWidget, SIGNAL(modified()), p, SIGNAL(modified()));
-        if (starRatingWidget != NULL)
-            disconnect(starRatingWidget, SIGNAL(modified()), p, SIGNAL(modified()));
+        if (fieldLineEdit != nullptr)
+            disconnect(fieldLineEdit, &FieldLineEdit::textChanged, p, &FieldInput::modified);
+        if (fieldListEdit != nullptr)
+            disconnect(fieldListEdit, &FieldListEdit::modified, p, &FieldInput::modified);
+        if (colorWidget != nullptr)
+            disconnect(colorWidget, &ColorLabelWidget::modified, p, &FieldInput::modified);
+        if (starRatingWidget != nullptr)
+            disconnect(starRatingWidget, &StarRatingFieldInput::modified, p, &FieldInput::modified);
     }
 };
 
@@ -295,6 +325,11 @@ bool FieldInput::apply(Value &value) const
     return d->apply(value);
 }
 
+bool FieldInput::validate(QWidget **widgetWithIssue, QString &message) const
+{
+    return d->validate(widgetWithIssue, message);
+}
+
 void FieldInput::setReadOnly(bool isReadOnly)
 {
     d->setReadOnly(isReadOnly);
@@ -322,14 +357,14 @@ void FieldInput::setCompletionItems(const QStringList &items)
 
 QWidget *FieldInput::buddy()
 {
-    if (d->fieldLineEdit != NULL)
+    if (d->fieldLineEdit != nullptr)
         return d->fieldLineEdit->buddy();
     // TODO fieldListEdit
-    else if (d->colorWidget != NULL)
+    else if (d->colorWidget != nullptr)
         return d->colorWidget;
-    else if (d->starRatingWidget != NULL)
+    else if (d->starRatingWidget != nullptr)
         return d->starRatingWidget;
-    return NULL;
+    return nullptr;
 }
 
 void FieldInput::setMonth(int month)
@@ -340,6 +375,14 @@ void FieldInput::setMonth(int month)
     emit modified();
 }
 
+void FieldInput::setEdition(int edition)
+{
+    Value value;
+    value.append(QSharedPointer<MacroKey>(new MacroKey(QString::number(edition))));
+    reset(value);
+    emit modified();
+}
+
 void FieldInput::selectCrossRef()
 {
     if (d->selectCrossRef())
