@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,21 +12,13 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "valuelistmodel.h"
 
 #include <typeinfo>
 
-#include <KComboBox>
-#include <KLocale>
-#include <KDebug>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <KColorScheme>
-#include <KLineEdit>
-
 #include <QApplication>
 #include <QTextDocument>
 #include <QAbstractTextDocumentLayout>
@@ -38,19 +30,25 @@
 #include <QLayout>
 #include <QHeaderView>
 
+#include <KComboBox>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <KColorScheme>
+#include <KLineEdit>
+
 #include "fieldlineedit.h"
 #include "bibtexfields.h"
 #include "entry.h"
 #include "preferences.h"
-#include "filemodel.h"
-
-const int CountRole = Qt::UserRole + 611;
+#include "models/filemodel.h"
+#include "logging_gui.h"
 
 QWidget *ValueListDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &sovi, const QModelIndex &index) const
 {
     if (index.column() == 0) {
-        const FieldDescription *fd = BibTeXFields::self()->find(m_fieldName);
-        FieldLineEdit *fieldLineEdit = new FieldLineEdit(fd->preferredTypeFlag, fd->typeFlags, false, parent);
+        const FieldDescription &fd = BibTeXFields::instance().find(m_fieldName);
+        FieldLineEdit *fieldLineEdit = new FieldLineEdit(fd.preferredTypeFlag, fd.typeFlags, false, parent);
         fieldLineEdit->setAutoFillBackground(true);
         return fieldLineEdit;
     } else
@@ -61,7 +59,7 @@ void ValueListDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
 {
     if (index.column() == 0) {
         FieldLineEdit *fieldLineEdit = qobject_cast<FieldLineEdit *>(editor);
-        if (fieldLineEdit != NULL)
+        if (fieldLineEdit != nullptr)
             fieldLineEdit->reset(index.model()->data(index, Qt::EditRole).value<Value>());
     }
 }
@@ -69,7 +67,7 @@ void ValueListDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
 void ValueListDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     FieldLineEdit *fieldLineEdit = qobject_cast<FieldLineEdit *>(editor);
-    if (fieldLineEdit != NULL) {
+    if (fieldLineEdit != nullptr) {
         Value v;
         fieldLineEdit->apply(v);
         if (v.count() == 1) /// field should contain exactly one value item (no zero, not two or more)
@@ -93,17 +91,18 @@ void ValueListDelegate::commitAndCloseEditor()
 
 void ValueListDelegate::initStyleOption(QStyleOptionViewItem *option, const QModelIndex &index) const
 {
-    QStyleOptionViewItemV4 *noTextOption = qstyleoption_cast<QStyleOptionViewItemV4 *>(option);
-    QStyledItemDelegate::initStyleOption(noTextOption, index);
+    QStyledItemDelegate::initStyleOption(option, index);
     if (option->decorationPosition != QStyleOptionViewItem::Top) {
         /// remove text from style (do not draw text)
-        noTextOption->text.clear();
+        option->text.clear();
     }
 
 }
 
-void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &_option, const QModelIndex &index) const
 {
+    QStyleOptionViewItem option = _option;
+
     /// code heavily inspired by kdepimlibs-4.6.3/akonadi/collectionstatisticsdelegate.cpp
 
     /// save painter's state, restored before leaving this function
@@ -115,14 +114,13 @@ void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 
     /// now, we retrieve the correct style option by calling intiStyleOption from
     /// the superclass.
-    QStyleOptionViewItemV4 option4 = option;
-    QStyledItemDelegate::initStyleOption(&option4, index);
-    QString field = option4.text;
+    QStyledItemDelegate::initStyleOption(&option, index);
+    QString field = option.text;
 
     /// now calculate the rectangle for the text
     QStyle *s = m_parent->style();
-    const QWidget *widget = option4.widget;
-    const QRect textRect = s->subElementRect(QStyle::SE_ItemViewItemText, &option4, widget);
+    const QWidget *widget = option.widget;
+    const QRect textRect = s->subElementRect(QStyle::SE_ItemViewItemText, &option, widget);
 
     if (option.state & QStyle::State_Selected) {
         /// selected lines are drawn with different color
@@ -130,7 +128,7 @@ void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     }
 
     /// count will be empty unless only one column is shown
-    const QString count = index.column() == 0 && index.model()->columnCount() == 1 ? QString(QLatin1String(" (%1)")).arg(index.data(CountRole).toInt()) : QLatin1String("");
+    const QString count = index.column() == 0 && index.model()->columnCount() == 1 ? QString(QStringLiteral(" (%1)")).arg(index.data(ValueListModel::CountRole).toInt()) : QString();
 
     /// squeeze the folder text if it is to big and calculate the rectangles
     /// where the folder text and the unread count will be drawn to
@@ -185,7 +183,6 @@ void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     painter->restore();
 }
 
-
 ValueListModel::ValueListModel(const File *bibtexFile, const QString &fieldName, QObject *parent)
         : QAbstractTableModel(parent), file(bibtexFile), fName(fieldName.toLower()), showCountColumn(true), sortBy(SortByText)
 {
@@ -221,7 +218,7 @@ QVariant ValueListModel::data(const QModelIndex &index, int role) const
         } else
             return QVariant(values[index.row()].count);
     } else if (role == SortRole) {
-        static const QRegExp ignoredInSorting("[{}\\\\]+");
+        static const QRegularExpression ignoredInSorting(QStringLiteral("[{}\\\\]+"));
 
         QString buffer = values[index.row()].sortBy.isEmpty() ? values[index.row()].text : values[index.row()].sortBy;
         buffer = buffer.remove(ignoredInSorting).toLower();
@@ -232,7 +229,7 @@ QVariant ValueListModel::data(const QModelIndex &index, int role) const
             /// Used if (a) two columns are shown (showCountColumn is true) and column 1
             /// (the count column) is to be sorted or (b) if only one column is shown
             /// (showCountColumn is false) and this single column is to be sorted by count.
-            return QString(QLatin1String("%1%2")).arg(values[index.row()].count, 10, 10, QLatin1Char('0')).arg(buffer);
+            return QString(QStringLiteral("%1%2")).arg(values[index.row()].count, 10, 10, QLatin1Char('0')).arg(buffer);
         } else {
             /// Otherwise use lower-case text for sorting
             return QVariant(buffer);
@@ -249,7 +246,7 @@ QVariant ValueListModel::data(const QModelIndex &index, int role) const
 
 bool ValueListModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    Q_ASSERT_X(file != NULL, "ValueListModel::setData", "You cannot set data if there is no BibTeX file associated with this value list.");
+    Q_ASSERT_X(file != nullptr, "ValueListModel::setData", "You cannot set data if there is no BibTeX file associated with this value list.");
 
     /// Continue only if in edit role and first column is to be changed
     if (role == Qt::EditRole && index.column() == 0) {
@@ -265,14 +262,14 @@ bool ValueListModel::setData(const QModelIndex &index, const QVariant &value, in
         /// Retrieve the Value object containing the user-entered data
         Value newValue = value.value<Value>(); /// nice variable names ... ;-)
         if (newValue.isEmpty()) {
-            kDebug() << "Cannot replace with empty value";
+            qCWarning(LOG_KBIBTEX_GUI) << "Cannot replace with empty value";
             return false;
         }
 
         /// Fetch the string representing the new, user-entered value
         const QString newText = PlainTextValue::text(newValue);
         if (newText == origText) {
-            kDebug() << "Skipping to replace value with itself";
+            qCWarning(LOG_KBIBTEX_GUI) << "Skipping to replace value with itself";
             return false;
         }
 
@@ -309,31 +306,34 @@ void ValueListModel::removeValue(const QModelIndex &index)
 
 void ValueListModel::setShowCountColumn(bool showCountColumn)
 {
+    beginResetModel();
     this->showCountColumn = showCountColumn;
-    reset();
+    endResetModel();
 }
 
 void ValueListModel::setSortBy(SortBy sortBy)
 {
+    beginResetModel();
     this->sortBy = sortBy;
-    reset();
+    endResetModel();
 }
 
 void ValueListModel::notificationEvent(int eventId)
 {
     if (eventId == NotificationHub::EventConfigurationChanged) {
+        beginResetModel();
         readConfiguration();
-        reset();
+        endResetModel();
     }
 }
 
 void ValueListModel::readConfiguration()
 {
     /// load mapping from color value to label
-    KSharedConfigPtr config(KSharedConfig::openConfig(QLatin1String("kbibtexrc")));
+    KSharedConfigPtr config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc")));
     KConfigGroup configGroup(config, Preferences::groupColor);
     QStringList colorCodes = configGroup.readEntry(Preferences::keyColorCodes, Preferences::defaultColorCodes);
-    QStringList colorLabels = configGroup.readEntry(Preferences::keyColorLabels, Preferences::defaultcolorLabels);
+    QStringList colorLabels = configGroup.readEntry(Preferences::keyColorLabels, Preferences::defaultColorLabels);
     colorToLabel.clear();
     for (QStringList::ConstIterator itc = colorCodes.constBegin(), itl = colorLabels.constBegin(); itc != colorCodes.constEnd() && itl != colorLabels.constEnd(); ++itc, ++itl) {
         colorToLabel.insert(*itc, i18n((*itl).toUtf8().constData()));
@@ -343,10 +343,10 @@ void ValueListModel::readConfiguration()
 void ValueListModel::updateValues()
 {
     values.clear();
-    if (file == NULL) return;
+    if (file == nullptr) return;
 
-    for (File::ConstIterator fit = file->constBegin(); fit != file->constEnd(); ++fit) {
-        QSharedPointer<const Entry> entry = (*fit).dynamicCast<const Entry>();
+    for (const auto &element : const_cast<const File &>(*file)) {
+        QSharedPointer<const Entry> entry = element.dynamicCast<const Entry>();
         if (!entry.isNull()) {
             for (Entry::ConstIterator eit = entry->constBegin(); eit != entry->constEnd(); ++eit) {
                 QString key = eit.key().toLower();
@@ -355,7 +355,7 @@ void ValueListModel::updateValues()
                     break;
                 }
                 if (eit.value().isEmpty())
-                    kWarning() << "value for key" << key << "in entry" << entry->id() << "is empty";
+                    qCWarning(LOG_KBIBTEX_GUI) << "value for key" << key << "in entry" << entry->id() << "is empty";
             }
         }
     }
@@ -363,7 +363,7 @@ void ValueListModel::updateValues()
 
 void ValueListModel::insertValue(const Value &value)
 {
-    foreach (const QSharedPointer<ValueItem> &item, value) {
+    for (const QSharedPointer<ValueItem> &item : value) {
         const QString text = PlainTextValue::text(*item);
         if (text.isEmpty()) continue; ///< skip empty values
 
@@ -379,7 +379,7 @@ void ValueListModel::insertValue(const Value &value)
             /// * for persons, use last name first
             /// * in any case, use lower case
             const QSharedPointer<Person> person = item.dynamicCast<Person>();
-            newValueLine.sortBy = person.isNull() ? text.toLower() : person->lastName().toLower() + QLatin1String(" ") + person->firstName().toLower();
+            newValueLine.sortBy = person.isNull() ? text.toLower() : person->lastName().toLower() + QStringLiteral(" ") + person->firstName().toLower();
 
             values << newValueLine;
         } else {
@@ -392,15 +392,15 @@ int ValueListModel::indexOf(const QString &text)
 {
     QString color;
     QString cmpText = text;
-    if (fName == Entry::ftColor && !(color = colorToLabel.key(text, QLatin1String(""))).isEmpty())
+    if (fName == Entry::ftColor && !(color = colorToLabel.key(text, QString())).isEmpty())
         cmpText = color;
     if (cmpText.isEmpty())
-        kWarning() << "Should never happen";
+        qCWarning(LOG_KBIBTEX_GUI) << "Should never happen";
 
     int i = 0;
     /// this is really slow for large data sets: O(n^2)
     /// maybe use a hash table instead?
-    foreach (const ValueLine &valueLine, values) {
+    for (const ValueLine &valueLine : const_cast<const ValueLineList &>(values)) {
         if (valueLine.text == cmpText)
             return i;
         ++i;
@@ -426,8 +426,8 @@ bool ValueListModel::searchAndReplaceValueInEntries(const QModelIndex &index, co
     }
 
     /// Go through all elements in the current file
-    for (File::ConstIterator it = file->constBegin(); it != file->constEnd(); ++it) {
-        QSharedPointer<Entry> entry = (*it).dynamicCast<Entry>();
+    for (const QSharedPointer<Element> &element : const_cast<const File &>(*file)) {
+        QSharedPointer<Entry> entry = element.dynamicCast<Entry>();
         /// Process only Entry objects
         if (!entry.isNull()) {
             /// Go through every key-value pair in entry (author, title, ...)
@@ -470,7 +470,7 @@ bool ValueListModel::searchAndReplaceValueInModel(const QModelIndex &index, cons
         values[row].text = newText;
         values[row].value = newValue;
         const QSharedPointer<Person> person = newValue.first().dynamicCast<Person>();
-        values[row].sortBy = person.isNull() ? QString() : person->lastName() + QLatin1String(" ") + person->firstName();
+        values[row].sortBy = person.isNull() ? QString() : person->lastName() + QStringLiteral(" ") + person->firstName();
     } else {
         /// The user-entered text existed before
 
@@ -508,8 +508,8 @@ void ValueListModel::removeValueFromEntries(const QModelIndex &index)
     }
 
     /// Go through all elements in the current file
-    for (File::ConstIterator it = file->constBegin(); it != file->constEnd(); ++it) {
-        QSharedPointer<Entry> entry = (*it).dynamicCast<Entry>();
+    for (const QSharedPointer<Element> &element : const_cast<const File &>(*file)) {
+        QSharedPointer<Entry> entry = element.dynamicCast<Entry>();
         /// Process only Entry objects
         if (!entry.isNull()) {
             /// Go through every key-value pair in entry (author, title, ...)
