@@ -1,5 +1,5 @@
 /*****************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
  *                                                                           *
  *                                                                           *
  *   This program is free software; you can redistribute it and/or modify    *
@@ -13,7 +13,7 @@
  *   GNU General Public License for more details.                            *
  *                                                                           *
  *   You should have received a copy of the GNU General Public License       *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.    *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.   *
  *****************************************************************************/
 
 #ifndef DOCKLET_FILESETTINGS_H
@@ -21,9 +21,10 @@
 
 #include "filesettingswidget.h"
 
+#include "openfileinfo.h"
+
 class FileView;
 class File;
-class OpenFileInfoManager;
 
 /**
  * @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
@@ -33,13 +34,14 @@ class FileSettings : public FileSettingsWidget
     Q_OBJECT
 
 public:
-    explicit FileSettings(OpenFileInfoManager *ofim, QWidget *parent);
+    explicit FileSettings(QWidget *parent);
 
     void setFileView(FileView *fileView);
 
 private slots:
     void widgetsChangedSlot();
     void currentFileChangedSlot();
+    void flagsChangedSlot(const OpenFileInfo::StatusFlags statusFlags);
 
 private:
     FileView *m_fileView;
