@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_PROGRAM_OPENFILEINFO_H
@@ -21,10 +21,10 @@
 #include <QObject>
 #include <QList>
 #include <QDateTime>
+#include <QUrl>
 #include <QVariant>
 
 #include <KService>
-#include <KUrl>
 
 #include "fileinfo.h"
 
@@ -40,9 +40,6 @@ class OpenFileInfo : public QObject
     Q_OBJECT
 
 public:
-    static const int FileIdStart = 0;
-    static const int FileIdInvalid = -1;
-
     enum StatusFlag {
         Open = 0x1,
         RecentlyUsed = 0x2,
@@ -51,14 +48,14 @@ public:
     };
     Q_DECLARE_FLAGS(StatusFlags, StatusFlag)
 
-    ~OpenFileInfo();
+    ~OpenFileInfo() override;
 
     KParts::ReadOnlyPart *part(QWidget *parent, KService::Ptr servicePtr = KService::Ptr());
 
     QString shortCaption() const;
     QString fullCaption() const;
     QString mimeType() const;
-    KUrl url() const;
+    QUrl url() const;
     bool isModified() const;
     bool save();
 
@@ -83,17 +80,15 @@ public:
     KService::Ptr defaultService();
     KService::Ptr currentService();
 
-    int fileId() const;
-
     friend class OpenFileInfoManager;
 
 signals:
     void flagsChanged(OpenFileInfo::StatusFlags statusFlags);
 
 protected:
-    OpenFileInfo(OpenFileInfoManager *openFileInfoManager, const KUrl &url);
+    OpenFileInfo(OpenFileInfoManager *openFileInfoManager, const QUrl &url);
     OpenFileInfo(OpenFileInfoManager *openFileInfoManager, const QString &mimeType = FileInfo::mimetypeBibTeX);
-    void setUrl(const KUrl &url);
+    void setUrl(const QUrl &url);
 
 private:
     class OpenFileInfoPrivate;
@@ -110,8 +105,8 @@ class OpenFileInfoManager: public QObject
 public:
     typedef QVector<OpenFileInfo *> OpenFileInfoList;
 
-    explicit OpenFileInfoManager(QWidget *parent);
-    ~OpenFileInfoManager();
+    static OpenFileInfoManager &instance();
+    ~OpenFileInfoManager() override;
 
     OpenFileInfo *createNew(const QString &mimeType = FileInfo::mimetypeBibTeX);
 
@@ -125,11 +120,11 @@ public:
      * @param url URL to bibliography file to open
      * @return an OpenFileInfo object representing the opened file
      */
-    OpenFileInfo *open(const KUrl &url);
+    OpenFileInfo *open(const QUrl &url);
 
-    OpenFileInfo *contains(const KUrl &url) const;
+    OpenFileInfo *contains(const QUrl &url) const;
     OpenFileInfo *currentFile() const;
-    bool changeUrl(OpenFileInfo *openFileInfo, const KUrl &url);
+    bool changeUrl(OpenFileInfo *openFileInfo, const QUrl &url);
     bool close(OpenFileInfo *openFileInfo);
 
     /**
@@ -151,7 +146,7 @@ public:
     bool queryCloseAll();
 
     void setCurrentFile(OpenFileInfo *openFileInfo, KService::Ptr servicePtr = KService::Ptr());
-    OpenFileInfoList filteredItems(OpenFileInfo::StatusFlags required, OpenFileInfo::StatusFlags forbidden = 0);
+    OpenFileInfoList filteredItems(OpenFileInfo::StatusFlags required, OpenFileInfo::StatusFlags forbidden = nullptr);
 
     friend class OpenFileInfo;
 
@@ -159,6 +154,9 @@ signals:
     void currentChanged(OpenFileInfo *, KService::Ptr);
     void flagsChanged(OpenFileInfo::StatusFlags statusFlags);
 
+protected:
+    explicit OpenFileInfoManager(QObject *parent);
+
 private:
     class OpenFileInfoManagerPrivate;
     OpenFileInfoManagerPrivate *d;
